@@ -3,6 +3,6 @@ package # hide from PAUSE
     
 use base qw/DBIx::Class::Schema/;
 
-__PACKAGE__->load_classes(qw/Test1 Test2/);
+__PACKAGE__->load_classes(qw/Test1 Test2 Test3/);
 
-1;
\ No newline at end of file
+1;
